@@ -131,6 +131,7 @@ netk_pager_get_type (void)
             sizeof (NetkPager),
             0,                  /* n_preallocs */
             (GInstanceInitFunc) netk_pager_init,
+            NULL		/* value_table */
         };
 
         object_type =
@@ -1353,7 +1354,7 @@ netk_pager_set_n_rows (NetkPager * pager, int n_rows)
 {
     g_return_if_fail (NETK_IS_PAGER (pager));
 
-    if (pager->priv->n_rows == n_rows)
+    if (pager->priv->n_rows == n_rows || n_rows <= 0)
         return;
 
     pager->priv->n_rows = n_rows;
