@@ -31,12 +31,17 @@
 #include <string.h>
 #endif
 
-#include <libxfce4util/utf8.h>
+#include <libxfce4util/libxfce4util.h>
 
 #include "netk-xutils.h"
 #include "netk-screen.h"
 #include "netk-private.h"
 #include "netk-inlinepixbufs.h"
+#include "xfce-icontheme.h"
+
+#ifndef XUrgencyHint
+#define XUrgencyHint (1L << 8)
+#endif
 
 gboolean
 p_netk_get_cardinal (Window xwindow, Atom atom, int *val)
@@ -255,7 +260,7 @@ p_netk_get_text_property (Window xwindow, Atom atom)
         retval = text_property_to_utf8 (&text);
         if (retval)
         {
-            utf8_string_remove_controls((gchar *) retval, -1, NULL);
+            xfce_utf8_remove_controls((gchar *) retval, -1, NULL);
         }
         if (text.nitems > 0)
             XFree (text.value);
@@ -298,7 +303,7 @@ p_netk_get_string_property_latin1 (Window xwindow, Atom atom)
         return NULL;
     }
 
-    retval = g_strdup (str);
+    retval = g_strdup ((gchar*) str);
 
     XFree (str);
 
@@ -338,15 +343,15 @@ p_netk_get_utf8_property (Window xwindow, Atom atom)
         return NULL;
     }
 
-    if (!g_utf8_validate (val, nitems, NULL))
+    if (!g_utf8_validate ((gchar*) val, nitems, NULL))
     {
         /* Property contained invalid UTF-8 */
         XFree (val);
         return NULL;
     }
 
-    utf8_string_remove_controls((gchar *) val, nitems, NULL);
-    retval = g_strndup (val, nitems);
+    xfce_utf8_remove_controls((gchar *) val, nitems, NULL);
+    retval = g_strndup ((gchar*) val, nitems);
 
     XFree (val);
 
@@ -540,7 +545,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
             return NULL;
         }
 
-        utf8_string_remove_controls((gchar *) p, -1, NULL);
+        xfce_utf8_remove_controls((gchar *) p, -1, NULL);
         retval[i] = g_strdup (p);
 
         p = p + strlen (p) + 1;
@@ -573,7 +578,7 @@ p_netk_set_utf8_list (Window xwindow, Atom atom, char **list)
     p_netk_error_trap_push ();
 
     XChangeProperty (gdk_display, xwindow, atom, utf8_string, 8,
-                     PropModeReplace, flattened->str, flattened->len);
+                     PropModeReplace, (unsigned char*) flattened->str, flattened->len);
 
     p_netk_error_trap_pop ();
 
@@ -976,6 +981,14 @@ p_netk_get_group_leader (Window xwindow)
     return ret;
 }
 
+char *
+p_netk_get_client_machine(Window xwindow)
+{
+	/* p_netk_get_string_property_latin1? */
+	return p_netk_get_string_property_latin1 (xwindow, p_netk_atom_get ("WM_CLIENT_MACHINE"));
+}
+
+
 char *
 p_netk_get_session_id (Window xwindow)
 {
@@ -1004,23 +1017,42 @@ p_netk_get_pid (Window xwindow)
         return val;
 }
 
+static gchar *
+netk_utf8_strndup (const gchar *src, gssize max_len)
+{
+    const gchar *s = src;
+
+    if (max_len <= 0)
+	return g_strdup (src);
+
+    while (max_len && *s)
+    {
+	s = g_utf8_next_char (s);
+	max_len--;
+    }
+
+    return g_strndup (src, s - src);
+}
+
 char *
 p_netk_get_name (Window xwindow)
 {
-    char *name;
+    char *s, *name = NULL;
 
-    name =
-        p_netk_get_utf8_property (xwindow,
-                                  p_netk_atom_get ("_NET_WM_VISIBLE_NAME"));
+    s = p_netk_get_utf8_property (xwindow, p_netk_atom_get ("_NET_WM_VISIBLE_NAME"));
 
-    if (name == NULL)
-        name =
-            p_netk_get_utf8_property (xwindow,
-                                      p_netk_atom_get ("_NET_WM_NAME"));
+    if (s == NULL)
+        s = p_netk_get_utf8_property (xwindow, p_netk_atom_get ("_NET_WM_NAME"));
 
-    if (name == NULL)
-        name = p_netk_get_text_property (xwindow, XA_WM_NAME);
+    if (s == NULL)
+        s = p_netk_get_text_property (xwindow, XA_WM_NAME);
 
+    if (s != NULL)
+    {
+        name = netk_utf8_strndup (s, NETK_MAX_TITLE_LENGTH);
+        g_free (s);
+    }
+    
     return name;
 }
 
@@ -1042,12 +1074,24 @@ latin1_to_utf8 (const char *latin1)
     return g_string_free (str, FALSE);
 }
 
-char *
+char*
 p_netk_get_res_class_utf8 (Window xwindow)
 {
+
+    char *res_class;
+
+    p_netk_get_wmclass (xwindow, &res_class, NULL);
+
+    return res_class;
+}
+
+void
+p_netk_get_wmclass (Window xwindow, char **res_class, char **res_name)
+{
+
     XClassHint ch;
     char *retval;
-
+  
     p_netk_error_trap_push ();
 
     ch.res_name = NULL;
@@ -1056,21 +1100,38 @@ p_netk_get_res_class_utf8 (Window xwindow)
     XGetClassHint (gdk_display, xwindow, &ch);
 
     p_netk_error_trap_pop ();
-
+  
     retval = NULL;
 
+
+    if (res_class)
+    {
+        *res_class = NULL;
+    }
+
+    if (res_name)
+    {
+        *res_name = NULL;
+    }
+
+  
     if (ch.res_name)
     {
+        if (res_name)
+        {
+            *res_name = latin1_to_utf8 (ch.res_name);
+        }
         XFree (ch.res_name);
     }
 
     if (ch.res_class)
     {
-        retval = latin1_to_utf8 (ch.res_class);
+        if (res_class)
+        {
+            *res_class = latin1_to_utf8 (ch.res_class);
+        }
         XFree (ch.res_class);
     }
-
-    return retval;
 }
 
 void
@@ -1101,7 +1162,7 @@ p_netk_select_input (Window xwindow, int mask)
  * from metacity, please sync bugfixes
  */
 static gboolean
-find_largest_sizes (gulong * data, int nitems, int *width, int *height)
+find_largest_sizes (gulong * data, gulong nitems, int *width, int *height)
 {
     *width = 0;
     *height = 0;
@@ -1133,7 +1194,7 @@ find_largest_sizes (gulong * data, int nitems, int *width, int *height)
 }
 
 static gboolean
-find_best_size (gulong * data, int nitems, int ideal_width, int ideal_height,
+find_best_size (gulong * data, gulong nitems, int ideal_width, int ideal_height,
                 int *width, int *height, gulong ** start)
 {
     int best_w;
@@ -1429,8 +1490,10 @@ get_cmap (GdkPixmap * pixmap)
     if (cmap
         && (gdk_colormap_get_visual (cmap)->depth !=
             gdk_drawable_get_depth (pixmap)))
+    {
+        g_object_unref (G_OBJECT (cmap));
         cmap = NULL;
-
+    }
     return cmap;
 }
 
@@ -1496,16 +1559,12 @@ try_pixmap_and_mask (Pixmap src_pixmap, Pixmap src_mask, GdkPixbuf ** iconp,
 
     get_pixmap_geometry (src_pixmap, &w, &h, NULL);
 
-    unscaled =
-        p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_pixmap, 0, 0, 0, 0, w,
-                                           h);
+    unscaled = p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_pixmap, 0, 0, 0, 0, w, h);
 
     if (unscaled && src_mask != None)
     {
         get_pixmap_geometry (src_mask, &w, &h, NULL);
-        mask =
-            p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_mask, 0, 0, 0, 0, w,
-                                               h);
+        mask = p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_mask, 0, 0, 0, 0, w, h);
     }
 
     p_netk_error_trap_pop ();
@@ -1526,20 +1585,16 @@ try_pixmap_and_mask (Pixmap src_pixmap, Pixmap src_mask, GdkPixbuf ** iconp,
     {
         *iconp =
             gdk_pixbuf_scale_simple (unscaled,
-                                     ideal_width >
-                                     0 ? ideal_width :
+                                     ideal_width > 0 ? ideal_width :
                                      gdk_pixbuf_get_width (unscaled),
-                                     ideal_height >
-                                     0 ? ideal_height :
+                                     ideal_height > 0 ? ideal_height :
                                      gdk_pixbuf_get_height (unscaled),
                                      GDK_INTERP_BILINEAR);
         *mini_iconp =
             gdk_pixbuf_scale_simple (unscaled,
-                                     ideal_mini_width >
-                                     0 ? ideal_mini_width :
+                                     ideal_mini_width > 0 ? ideal_mini_width :
                                      gdk_pixbuf_get_width (unscaled),
-                                     ideal_mini_height >
-                                     0 ? ideal_mini_height :
+                                     ideal_mini_height > 0 ? ideal_mini_height :
                                      gdk_pixbuf_get_height (unscaled),
                                      GDK_INTERP_BILINEAR);
 
@@ -1789,6 +1844,26 @@ scaled_from_pixdata (guchar * pixdata, int w, int h, int new_w, int new_h)
     return dest;
 }
 
+gboolean
+p_netk_is_urgent (Window xwindow)
+{
+    XWMHints *hints;
+    gboolean retval;
+    retval = FALSE;
+    
+    p_netk_error_trap_push ();
+    hints = XGetWMHints (gdk_display, xwindow);
+    p_netk_error_trap_pop ();
+    
+    if (hints)
+    {
+        retval = (hints->flags & XUrgencyHint);
+        XFree (hints);
+        hints = NULL;
+    }
+    return retval;
+}
+  
 gboolean
 p_netk_read_icons (Window xwindow, NetkIconCache * icon_cache,
                    GdkPixbuf ** iconp, int ideal_width, int ideal_height,
@@ -1963,8 +2038,29 @@ default_icon_at_size (int width, int height)
 {
 
     GdkPixbuf *base;
+    GdkPixbuf *nbase;
+    XfceIconTheme *theme;
+    base = NULL;
+    
+    if (width > 0) {
+        theme = xfce_icon_theme_get_for_screen (NULL);
+        if (theme) {
+            if (!base) base = xfce_icon_theme_load_category (theme, XFCE_ICON_CATEGORY_UNKNOWN, width);
+            if (!base) base = xfce_icon_theme_load (theme, "xfce-unknown", width);
+            if (!base) base = xfce_icon_theme_load (theme, "unknown", width);
+        
+            g_object_unref (G_OBJECT (theme));
+        }
+        if (base) {
+        	nbase = gdk_pixbuf_copy (base);
+        	g_object_unref (G_OBJECT (base));
+        	base = nbase;
+        	nbase = NULL;
+        }
+    }
 
-    base = gdk_pixbuf_new_from_inline (-1, default_icon_data, FALSE, NULL);
+    if(!base)
+        base = gdk_pixbuf_new_from_inline (-1, default_icon_data, FALSE, NULL);
 
     g_assert (base);
 
@@ -1998,18 +2094,19 @@ p_netk_get_fallback_icons (GdkPixbuf ** iconp, int ideal_width,
                            int ideal_height, GdkPixbuf ** mini_iconp,
                            int ideal_mini_width, int ideal_mini_height)
 {
-    *iconp =
-        default_icon_at_size (ideal_width >
-                              0 ? ideal_width : DEFAULT_ICON_WIDTH,
-                              ideal_height >
-                              0 ? ideal_height : DEFAULT_ICON_HEIGHT);
+    if (iconp)
+        *iconp =
+            default_icon_at_size (ideal_width > 0 ? ideal_width : 
+                                  DEFAULT_ICON_WIDTH,
+                                  ideal_height > 0 ? ideal_height : 
+                                  DEFAULT_ICON_HEIGHT);
 
-    *mini_iconp =
-        default_icon_at_size (ideal_mini_width >
-                              0 ? ideal_mini_width : DEFAULT_MINI_ICON_WIDTH,
-                              ideal_mini_height >
-                              0 ? ideal_mini_height :
-                              DEFAULT_MINI_ICON_HEIGHT);
+    if (mini_iconp)
+        *mini_iconp =
+            default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width : 
+                                  DEFAULT_MINI_ICON_WIDTH,
+                                  ideal_mini_height > 0 ? ideal_mini_height :
+                                  DEFAULT_MINI_ICON_HEIGHT);
 }
 
 
@@ -2017,7 +2114,8 @@ void
 p_netk_get_window_geometry (Screen * screen, Window xwindow, int *xp, int *yp,
                             int *widthp, int *heightp)
 {
-    int x, y, width, height, bw, depth;
+    int x, y;
+    unsigned int width, height, bw, depth;
     Window root_window;
 
     width = 1;
@@ -2033,9 +2131,9 @@ p_netk_get_window_geometry (Screen * screen, Window xwindow, int *xp, int *yp,
     p_netk_get_window_position (screen, xwindow, xp, yp);
 
     if (widthp)
-        *widthp = width;
+        *widthp = (int) width;
     if (heightp)
-        *heightp = height;
+        *heightp = (int) height;
 }
 
 void
