@@ -113,7 +113,8 @@ xfce_decortoggle_get_type (void)
 	    NULL,		/* class_data */
 	    sizeof (XfceDecortoggle),
 	    0,			/* n_preallocs */
-	    (GInstanceInitFunc) xfce_decortoggle_init
+	    (GInstanceInitFunc) xfce_decortoggle_init,
+	    NULL		/* value_table */
 	};
 
 	decortoggle_type =
@@ -285,21 +286,21 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     if (!(decortoggle->arrow_up_dark_bmap))
     {
 	decortoggle->arrow_up_dark_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_up_dark_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_up_dark_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
     if (!(decortoggle->arrow_up_mid_bmap))
     {
 	decortoggle->arrow_up_mid_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_up_mid_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_up_mid_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
     if (!(decortoggle->arrow_up_light_bmap))
     {
 	decortoggle->arrow_up_light_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_up_light_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_up_light_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -307,14 +308,14 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     if (!(decortoggle->arrow_down_dark_bmap))
     {
 	decortoggle->arrow_down_dark_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_down_dark_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_down_dark_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
     if (!(decortoggle->arrow_down_mid_bmap))
     {
 	decortoggle->arrow_down_mid_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_down_mid_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_down_mid_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -322,7 +323,7 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     {
 	decortoggle->arrow_down_light_bmap =
 	    gdk_bitmap_create_from_data (widget->window,
-					 arrow_down_light_bits,
+					 (gchar*) arrow_down_light_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -330,14 +331,14 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     if (!(decortoggle->arrow_left_dark_bmap))
     {
 	decortoggle->arrow_left_dark_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_left_dark_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_left_dark_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
     if (!(decortoggle->arrow_left_mid_bmap))
     {
 	decortoggle->arrow_left_mid_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_left_mid_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_left_mid_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -345,7 +346,7 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     {
 	decortoggle->arrow_left_light_bmap =
 	    gdk_bitmap_create_from_data (widget->window,
-					 arrow_left_light_bits,
+					 (gchar*) arrow_left_light_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -354,14 +355,14 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     {
 	decortoggle->arrow_right_dark_bmap =
 	    gdk_bitmap_create_from_data (widget->window,
-					 arrow_right_dark_bits,
+					 (gchar*) arrow_right_dark_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
     if (!(decortoggle->arrow_right_mid_bmap))
     {
 	decortoggle->arrow_right_mid_bmap =
-	    gdk_bitmap_create_from_data (widget->window, arrow_right_mid_bits,
+	    gdk_bitmap_create_from_data (widget->window, (gchar*) arrow_right_mid_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
@@ -369,7 +370,7 @@ initialize_decortoggle_bmap (GtkWidget * widget)
     {
 	decortoggle->arrow_right_light_bmap =
 	    gdk_bitmap_create_from_data (widget->window,
-					 arrow_right_light_bits,
+					 (gchar*) arrow_right_light_bits,
 					 decortoggle_WIDTH,
 					 decortoggle_HEIGHT);
     }
