@@ -1,4 +1,4 @@
-/* $Id: xfce_iconbutton.c 1550 2004-10-28 12:50:23Z jasper $
+/* $Id: xfce_iconbutton.c 19500 2006-01-19 17:45:06Z daichi $
  * 
  * Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
@@ -74,7 +74,8 @@ xfce_iconbutton_get_type (void)
 	    NULL,		/* class_data */
 	    sizeof (XfceIconbutton),
 	    0,			/* n_preallocs */
-	    (GInstanceInitFunc) xfce_iconbutton_init
+	    (GInstanceInitFunc) xfce_iconbutton_init,
+	    NULL		/* value_table */
 	};
 
 	iconbutton_type =
