@@ -114,14 +114,15 @@ xfce_system_tray_get_type (void)
     {
         static const GTypeInfo xfce_system_tray_info = {
             sizeof (XfceSystemTrayClass),
-            NULL,
-            NULL,
+            NULL,		/* base_init */
+            NULL,		/* base_finalize */
             (GClassInitFunc) xfce_system_tray_class_init,
-            NULL,
-            NULL,
+            NULL,		/* class_finalize */
+            NULL,		/* class_data */
             sizeof (XfceSystemTray),
-            0,
-            (GInstanceInitFunc) xfce_system_tray_init
+            0,			/* n_preallocs */
+            (GInstanceInitFunc) xfce_system_tray_init,
+            NULL		/* value_table */
         };
 
         xfce_system_tray_type = g_type_register_static (G_TYPE_OBJECT,
@@ -426,7 +427,9 @@ xfce_system_tray_dock_request (XClientMessageEvent * xev,
     GtkWidget *icon;
     GtkSocket *socket;
     Window *xwindow;
+#ifdef ENABLE_KDE_SYSTRAY_PROXY
     GtkRequisition req;
+#endif
 
     if (g_hash_table_lookup (tray->sockets, GINT_TO_POINTER (xev->data.l[2])))
     {
@@ -467,7 +470,8 @@ xfce_system_tray_dock_request (XClientMessageEvent * xev,
          * add the socket to the list of known sockets
          */
         g_hash_table_insert (tray->sockets, GINT_TO_POINTER (xev->data.l[2]), GTK_SOCKET (icon));
-                
+
+#ifdef ENABLE_KDE_SYSTRAY_PROXY
         /*
          * Make sure the icons have a meaningfull size ...
          */ 
@@ -481,6 +485,7 @@ xfce_system_tray_dock_request (XClientMessageEvent * xev,
                         req.width, req.height, nw, nh);
             gtk_widget_set_size_request(icon, nw,  nh);
         }
+#endif
         gtk_widget_show(icon);
     }
     else
